# Kitty and John
# 10.12.2021
# Differential abundance analysis of samples

# Load libraries
library(tidyverse)
library(vegan)
library(ape)
library(phyloseq)
library(DESeq2)
library(pheatmap)
library(RColorBrewer)
library(VennDiagram)

# Create necessary functions
# Relative abundance function
calculate_relative_abundance <- function(x) x / sum(x)

# Geometric mean function
calculate_gm_mean <- function(x, na.rm = TRUE) {
  exp(sum(log(x[x > 0]), na.rm = na.rm) / length(x))
}

# Plotting function
Plot_DA <- function (val) {
  
  DA <- ggplot(val, aes(x = log2FoldChange, y = Genus, fill = SIGN)) +
    geom_bar(stat = "identity", width = 1) +
    labs(
      x = expression(log[2]~fold~change),
      y = "Genus") +
    theme_bw()
  
  # Colours: "#E87E71","#55BCC2"
  
  DA <- DA + theme(panel.grid.major = element_blank(), 
                   panel.grid.minor = element_blank(), 
                   text=element_text(size = 16))
  DA
  
}

# Set seed
set.seed(711)

# Import data
biom_file <- import_biom("table-with-taxonomy.biom")
metadata  <- import_qiime_sample_data("sample-metadata.tsv")
tree      <- read_tree_greengenes("tree.nwk")

tree <- multi2di(tree)

# Create physeq object
physeq <- merge_phyloseq(biom_file, metadata, tree)

# Add labels for taxonomic levels
colnames(tax_table(physeq)) <- c("Kingdom", "Phylum", "Class","Order", "Family",
                                 "Genus", "Species")

# Data processing (DESeq2) starts here

# Filtering data by sequencing depth
at_least_1000 <- prune_samples(sample_sums(physeq) >= 1000, physeq)
sample_sums(at_least_1000)

# Filter by metadata 

sample_data(physeq)

building <- subset_samples(physeq, env_feature == "building")
building

# Removing low-abundant features
building_counts <- taxa_sums(building)
relative_abundance_building <- calculate_relative_abundance(building_counts)
abundant_building <- relative_abundance_building > 0.0005
abundant_building_taxa <- prune_taxa(abundant_building, building)

# Setting taxonomic level for analysis - tax_glom removes zeros from abundance data
abundant_building_genera <- tax_glom(abundant_building_taxa, taxrank = "Genus")
abundant_building_genera

# Comparing kitchen counter (wood) to all plastic samples
sample_data(abundant_building_genera)$orig_env_material <-
  factor(sample_data(abundant_building_genera)$orig_env_material,
         levels = c("wood", "plastic"))

# Creating DESeq object
deseq_building <- phyloseq_to_deseq2(abundant_building_genera, ~ orig_env_material)

geo_means <- apply(counts(deseq_building), 1, calculate_gm_mean)

deseq_building <- estimateSizeFactors(deseq_building, geoMeans = geo_means)

deseq_building <- DESeq(deseq_building, fitType = "local")

# Getting names of all performed comparisons
resultsNames(deseq_building)

# Selecting abundance comparison here

# Plastic versus Wood
building_diff_abund_plastic_vs_wood <- results(deseq_building, name = "orig_env_material_plastic_vs_wood")

# Setting alpha as 0.05
alpha <- 0.05

# Filtering by alpha
building_diff_abund_plastic_vs_wood <- as.data.frame(building_diff_abund_plastic_vs_wood)
building_diff_abund_plastic_vs_wood <- filter(building_diff_abund_plastic_vs_wood, padj < alpha)


# Merging the table with signifcant results with the table of taxonomic information.
genera_df <- as.data.frame(tax_table(abundant_building_genera))
building_diff_abund_plastic_vs_wood <- merge(building_diff_abund_plastic_vs_wood, genera_df, by = "row.names")
building_diff_abund_plastic_vs_wood <- arrange(building_diff_abund_plastic_vs_wood, log2FoldChange)

dim(building_diff_abund_plastic_vs_wood)

building_diff_abund_plastic_vs_wood

# Preparing for ggplot, adding a column of sign values for colouring purposes
building_diff_abund_plastic_vs_wood <- mutate(building_diff_abund_plastic_vs_wood,
              Genus = factor(Genus, levels = Genus))


building_diff_abund_plastic_vs_wood <- mutate(building_diff_abund_plastic_vs_wood,
              SIGN = factor(sign(building_diff_abund_plastic_vs_wood$log2FoldChange) * -1))

# Plotting differential abundance data for plastic versus wood
Plot_DA(building_diff_abund_plastic_vs_wood)

# Comparing kitchen counter (wood) to each plastic sample
sample_data(abundant_building_genera)$sample_origin <-
  factor(sample_data(abundant_building_genera)$sample_origin,
         levels = c("KC", "BR", "TB", "MR"))

deseq_building <- phyloseq_to_deseq2(abundant_building_genera, ~ sample_origin)

geo_means <- apply(counts(deseq_building), 1, calculate_gm_mean)

deseq_building <- estimateSizeFactors(deseq_building, geoMeans = geo_means)

deseq_building <- DESeq(deseq_building, fitType = "local")

# Get names of all performed comparisons
resultsNames(deseq_building)

# Select abundance comparison here
#Bed Room versus Kitchen Counter
building_diff_abund_BR_vs_KC <- results(deseq_building, name = "sample_origin_BR_vs_KC")

# Filtering by alpha
building_diff_abund_BR_vs_KC <- as.data.frame(building_diff_abund_BR_vs_KC)
building_diff_abund_BR_vs_KC <- filter(building_diff_abund_BR_vs_KC, padj < alpha)


# Merging the table with signifcant results with the table of taxonomic information. 

genera_df <- as.data.frame(tax_table(abundant_building_genera))
building_diff_abund_BR_vs_KC <- merge(building_diff_abund_BR_vs_KC, genera_df, by = "row.names")
building_diff_abund_BR_vs_KC <- arrange(building_diff_abund_BR_vs_KC, log2FoldChange)

dim(building_diff_abund_BR_vs_KC)

building_diff_abund_BR_vs_KC

# Preparing for ggplot, adding a column of sign values for colouring purposes
building_diff_abund_BR_vs_KC <- mutate(building_diff_abund_BR_vs_KC,
              Genus = factor(Genus, levels = Genus))


building_diff_abund_BR_vs_KC <- mutate(building_diff_abund_BR_vs_KC,
              SIGN = factor(sign(building_diff_abund_BR_vs_KC$log2FoldChange) * -1))

# Extracting a vector of genus names for more abundant taxa in wood in Bed Room vs Kitchen Counter
VENN_Vec_BR_vs_KC_W <- building_diff_abund_BR_vs_KC %>% 
  filter(SIGN == 1)

VENN_Vec_BR_vs_KC_W <- c(VENN_Vec_BR_vs_KC_W$Genus)

VENN_Vec_BR_vs_KC_W

# Extracting a vector of genus names for more abundant taxa in plastic in Bed Room vs Kitchen Counter
VENN_Vec_BR_vs_KC_P <- building_diff_abund_BR_vs_KC %>% 
  filter(SIGN == -1)

VENN_Vec_BR_vs_KC_P <- c(VENN_Vec_BR_vs_KC_P$Genus)

VENN_Vec_BR_vs_KC_P

# Plotting differential abundance data for Bed Room vs Kitchen Counter
Plot_DA(building_diff_abund_BR_vs_KC)

# Repeat for all sample categories
# Main Room versus Kitchen Counter
building_diff_abund_MR_vs_KC <- results(deseq_building, name = "sample_origin_MR_vs_KC")

# Filtering by alpha
building_diff_abund_MR_vs_KC <- as.data.frame(building_diff_abund_MR_vs_KC)
building_diff_abund_MR_vs_KC <- filter(building_diff_abund_MR_vs_KC, padj < alpha)


# Merging the table with signifcant results with the table of taxonomic information. 

genera_df <- as.data.frame(tax_table(abundant_building_genera))
building_diff_abund_MR_vs_KC <- merge(building_diff_abund_MR_vs_KC, genera_df, by = "row.names")
building_diff_abund_MR_vs_KC <- arrange(building_diff_abund_MR_vs_KC, log2FoldChange)

dim(building_diff_abund_MR_vs_KC)

building_diff_abund_MR_vs_KC

# Preparing for ggplot, adding a column of sign values for colouring purposes
building_diff_abund_MR_vs_KC <- mutate(building_diff_abund_MR_vs_KC,
                                       Genus = factor(Genus, levels = Genus))


building_diff_abund_MR_vs_KC <- mutate(building_diff_abund_MR_vs_KC,
                                       SIGN = factor(sign(building_diff_abund_MR_vs_KC$log2FoldChange) * -1))

# Extracting a vector of genus names for more abundant taxa in wood in main Room vs Kitchen Counter
VENN_Vec_MR_vs_KC_W <- building_diff_abund_MR_vs_KC %>% 
  filter(SIGN == 1)

VENN_Vec_MR_vs_KC_W <- c(VENN_Vec_MR_vs_KC_W$Genus)

VENN_Vec_MR_vs_KC_W

# Extracting a vector of genus names for more abundant taxa in plastic in Main Room vs Kitchen Counter
VENN_Vec_MR_vs_KC_P <- building_diff_abund_MR_vs_KC %>% 
  filter(SIGN == -1)

VENN_Vec_MR_vs_KC_P <- c(VENN_Vec_MR_vs_KC_P$Genus)

VENN_Vec_MR_vs_KC_P

#  Plotting differential abundance data for Main Room vs Kitchen Counter
Plot_DA(building_diff_abund_MR_vs_KC)

# Toilet Bowl versus Kitchen Counter
building_diff_abund_TB_vs_KC <- results(deseq_building, name = "sample_origin_TB_vs_KC")

alpha <- 0.05
building_diff_abund_TB_vs_KC <- as.data.frame(building_diff_abund_TB_vs_KC)
building_diff_abund_TB_vs_KC <- filter(building_diff_abund_TB_vs_KC, padj < alpha)


# Merging the table with signifcant results with the table of taxonomic information. 

genera_df <- as.data.frame(tax_table(abundant_building_genera))
building_diff_abund_TB_vs_KC <- merge(building_diff_abund_TB_vs_KC, genera_df, by = "row.names")
building_diff_abund_TB_vs_KC <- arrange(building_diff_abund_TB_vs_KC, log2FoldChange)

dim(building_diff_abund_TB_vs_KC)

building_diff_abund_TB_vs_KC

# Preparing for ggplot, adding a column of sign values for colouring purposes
building_diff_abund_TB_vs_KC <- mutate(building_diff_abund_TB_vs_KC,
                                       Genus = factor(Genus, levels = Genus))


building_diff_abund_TB_vs_KC <- mutate(building_diff_abund_TB_vs_KC,
                                       SIGN = factor(sign(building_diff_abund_TB_vs_KC$log2FoldChange) * -1))

# Extracting a vector of genus names for more abundant taxa in wood in Toilet Bowl versus Kitchen Counter
VENN_Vec_TB_vs_KC_W <- building_diff_abund_TB_vs_KC %>% 
  filter(SIGN == 1)

VENN_Vec_TB_vs_KC_W <- c(VENN_Vec_TB_vs_KC_W$Genus)

VENN_Vec_TB_vs_KC_W

# Extracting a vector of genus names for more abundant taxa in plastic in Toilet Bowl versus Kitchen Counter
VENN_Vec_TB_vs_KC_P <- building_diff_abund_TB_vs_KC %>% 
  filter(SIGN == -1)

VENN_Vec_TB_vs_KC_P <- c(VENN_Vec_TB_vs_KC_P$Genus)

VENN_Vec_TB_vs_KC_P

# Plotting differential abundance data for Toilet Bowl versus Kitchen Counter
Plot_DA(building_diff_abund_TB_vs_KC)

# Making the Venn diagram for strains more abundant in wood relative to each sample type
# Assigning colours for the plot 
MyColWood = c("#55BCC2", "#55BCC2", "#55BCC2")
          
# Generating venn diagram 
# WARNING: This saves to a file in your working directory - does not show up in "plots"
venn.diagram(
  x = list(VENN_Vec_BR_vs_KC_W, VENN_Vec_MR_vs_KC_W, VENN_Vec_TB_vs_KC_W),
  category.names = c("Bed Room" , "Main Room", "Toilet Bowl"),
  fill = MyColWood,
  filename = '#14_venn_diagramm.png',
  output=TRUE
)

# Making the Venn diagram for strains more abundant in plastic relative to each sample type
# Assigning colours for the plot
MyColPlastic = c("#E87E71", "indianred3", "orange")

# Generating venn diagram 
# WARNING: This saves to a file in your working directory - does not show up in "plots"
venn.diagram(
  x = list(VENN_Vec_BR_vs_KC_P, VENN_Vec_MR_vs_KC_P, VENN_Vec_TB_vs_KC_P),
  category.names = c("Bed Room" , "Main Room", "Toilet Bowl"),
  fill = MyColPlastic,
  filename = '#15_venn_diagramm.png',
  output=TRUE
)

