# John and Kitty
# 25.11.2021
# Making a heatmap of related strains

library(tidyverse)
library(vegan)
library(ape)
library(phyloseq)
library(DESeq2)
library(pheatmap)
library(RColorBrewer)
library("dplyr")
library("ggplot2")
library("genefilter")

# Create necessary functions
# Relative abundance function
calculate_relative_abundance <- function(x) x / sum(x)

# Geometric mean function
calculate_gm_mean <- function(x, na.rm = TRUE) {
  exp(sum(log(x[x > 0]), na.rm = na.rm) / length(x))
}

# Set seed
set.seed(711)

# Import data
biom_file <- import_biom("table-with-taxonomy.biom")
metadata  <- import_qiime_sample_data("sample-metadata.tsv")
tree      <- read_tree_greengenes("tree.nwk")

tree <- multi2di(tree)

# Creating physeq object
physeq <- merge_phyloseq(biom_file, metadata, tree)

# Add labels for taxonomic levels
colnames(tax_table(physeq)) <- c("Kingdom", "Phylum", "Class","Order", "Family",
                                 "Genus", "Species")

head(tax_table(physeq))

# Data processing (DESeq2) starts here

# Filtering data by sequencing depth
at_least_1000 <- prune_samples(sample_sums(physeq) >= 1000, physeq)
sample_sums(at_least_1000)

# Filtering by metadata 

sample_data(physeq)

building <- subset_samples(physeq, env_feature == "building")
building

# Removing low-abundant features
building_counts <- taxa_sums(building)
relative_abundance_building <- calculate_relative_abundance(building_counts)
abundant_building <- relative_abundance_building > 0.0005
abundant_building_taxa <- prune_taxa(abundant_building, building)

# Setting taxonomic level for analysis - tax_glom removes zeros from abundance data
abundant_building_genera <- tax_glom(abundant_building_taxa, taxrank = "Genus")
abundant_building_genera

# Comparing kitchen counter (wood) to all plastic samples
sample_data(abundant_building_genera)$description <-
  factor(sample_data(abundant_building_genera)$description,
         levels=c(
           "kitchen_counter", "bed_room", "main_room", "toilet_bowl"), 
         labels=c("Kitchen Counter (Wood)", "Bed Room", "Main Room", "Toilet Bowl"))

sample_data(abundant_building_genera)$orig_env_material <-
  factor(sample_data(abundant_building_genera)$orig_env_material,
         levels=c(
           "wood", "plastic"), 
         labels=c("Wood", "Plastic"))

# Creating Deseq object
deseq_building <- phyloseq_to_deseq2(abundant_building_genera, ~ description)
geo_means <- apply(counts(deseq_building), 1, calculate_gm_mean)
deseq_building <- estimateSizeFactors(deseq_building, geoMeans = geo_means)
deseq_building <- DESeq(deseq_building, fitType = "local")

# Getting names of all performed comparisons
resultsNames(deseq_building)

# Making a heatmap  
#https://master.bioconductor.org/packages/release/workflows/vignettes/rnaseqGene/inst/doc/rnaseqGene.html#preparing-quantification-input-to-deseq2

# VST method (104 samples total, therefore prefer over rlog)
vsd <- vst(deseq_building, nsub = 49, blind = FALSE)
head(assay(vsd), 3)


# Calculating sample distances
sampleDists <- dist(t(assay(vsd)))
sampleDists

# Plotting distance matrix
# Add names here to compare sample to sample 
sampleDistMatrix <- as.matrix( sampleDists )
rownames(sampleDistMatrix) <- paste( vsd$orig_env_material, vsd$description, sep = " - " )
colnames(sampleDistMatrix) <- NULL
colors <- colorRampPalette( rev(brewer.pal(9, "Blues")) )(255)
pheatmap(sampleDistMatrix,
         clustering_distance_rows = sampleDists,
         clustering_distance_cols = sampleDists,
         col = colors)

# Pulling out most differentially abundant taxa
topVarTaxa <- head(order(rowVars(assay(vsd)), decreasing = TRUE), 20)

# Plotting heatmap
mat  <- assay(vsd)[ topVarTaxa, ]
Legend_Colours <- list(
  description = c("Kitchen Counter (Wood)" = "#55BCC2", "Bed Room" = "#E87E71", "Main Room" = "indianred3", "Toilet Bowl" = "orange"),
  orig_env_material = c(Wood = "#55BCC2", Plastic = "#E87E71")
  
)

mat  <- mat - rowMeans(mat)
anno <- as.data.frame(colData(vsd)[c("orig_env_material","description")])
pheatmap(mat, annotation_col = anno, 
         annotation_colors = Legend_Colours,
         show_rownames = FALSE,
         show_colnames = FALSE)
