# John and Kitty
# 24.11.2021
# Making unweighted unifrac PCoA plots 

# load libraries
library(tidyverse)
library(vegan)
library(ape)
library(phyloseq)
library(DESeq2)
library(pheatmap)
library(RColorBrewer)

# Create necessary functions
# Relative abundance function
calculate_relative_abundance <- function(x) x / sum(x)

# Geometric mean function
calculate_gm_mean <- function(x, na.rm = TRUE) {
  exp(sum(log(x[x > 0]), na.rm = na.rm) / length(x))
}

# Set seed
set.seed(711)

# Import data
biom_file <- import_biom("table-with-taxonomy.biom")
metadata  <- import_qiime_sample_data("sample-metadata.tsv")
tree      <- read_tree_greengenes("tree.nwk")

tree <- multi2di(tree)

# Create physeq object
physeq <- merge_phyloseq(biom_file, metadata, tree)

# Add labels for taxonomic levels
colnames(tax_table(physeq)) <- c("Kingdom", "Phylum", "Class","Order", "Family",
                                 "Genus", "Species")

# Making PCoA plots - unweighted unifrac
# Rarefaction
physeq_rar <-  rarefy_even_depth(physeq,sample.size = 1250)

# Re-ordering and re-labelling categories
physeq_rar@sam_data$description <- factor(physeq_rar@sam_data$description, 
                                          levels=c(
                                             "bed_room", "main_room", "toilet_bowl", "kitchen_counter"), 
  labels=c("Bed Room", "Main Room", "Toilet Bowl", "Kitchen Counter (Wood)"))

# Calculating diversity
ord <- ordinate(physeq_rar, method = "PCoA",
                distance = "wunifrac"
                # # Uncomment to run Unweighted Unifrac method
                # distance = "uwunifrac"
                # 
                # # Uncomment to run Bray-Curtis method
                # distance = "bray"
                # 
                # # Uncomment to run Jaccard method
                # distance = "jaccard",
                # binary = TRUE
                )

# Plotting for differences based on surface material
UwUmaterial <- plot_ordination(physeq_rar,
                ord,
                color = "orig_env_material") +
  # labs(title = "Our Unweighted Unifrac") +
  theme_bw() +
  stat_ellipse(type = "norm", size = 0.5) +
  scale_colour_manual(
    values = c("#E87E71", "#55BCC2"),
    labels = c("Plastic", "Wood")) +
  guides(color = guide_legend("
  Original 
  Environmental 
  Material"))

UwUmaterial <- UwUmaterial + 
  # ggtitle("Our Unweighted Unifrac") +
  theme(plot.title = element_text(hjust = 0.5))


UwUmaterial <- UwUmaterial + theme(panel.grid.major = element_blank(), 
               panel.grid.minor = element_blank(), 
               text=element_text(size = 16))

UwUmaterial

# Plotting for differences based on description/location
UwUdesc <- plot_ordination(physeq_rar,
                                 ord,
                                 color = "description") +
  labs() +
  theme_bw() +
  stat_ellipse(type = "norm", size = 0.5) +
  scale_colour_manual(
    values = c("orange", "#E87E71", "indianred3", "#55BCC2")) +
  guides(color = guide_legend("Location"))

UwUdesc <- UwUdesc + theme(panel.grid.major = element_blank(), 
                                   panel.grid.minor = element_blank(), 
                                   text=element_text(size = 16))

UwUdesc

