# Kitty and John
# 10.12.2021
# Facet plots of relative abundance

library(tidyverse)
library(vegan)
library(ape)
library(phyloseq)
library(DESeq2)
calculate_relative_abundance <- function(x) x / sum(x)

calculate_gm_mean <- function(x, na.rm = TRUE) {
  exp(sum(log(x[x > 0]), na.rm = na.rm) / length(x))
}

set.seed(711)

biom_file <- import_biom("table-with-taxonomy.biom")
metadata  <- import_qiime_sample_data("sample-metadata.tsv")
tree      <- read_tree_greengenes("tree.nwk")

tree <- multi2di(tree)

physeq <- merge_phyloseq(biom_file, metadata, tree)

physeq

head(sample_data(physeq))

head(tax_table(physeq))

colnames(tax_table(physeq)) <- c("Kingdom", "Phylum", "Class","Order", "Family",
                                 "Genus", "Species")

head(tax_table(physeq))

#data processing (DESeq2) starts here

#Filtering data by sequencing depth

sample_sums(physeq)

sample_sums(physeq) >= 1000

at_least_1000 <- prune_samples(sample_sums(physeq) >= 1000, physeq)
sample_sums(at_least_1000)

#Filter by metadata 

sample_data(physeq)

building <- subset_samples(physeq, env_feature == "building")
building

no_building <- subset_samples(physeq, env_feature != "building")

#Remove low-abundant features

building_counts <- taxa_sums(building)
relative_abundance_building <- calculate_relative_abundance(building_counts)
abundant_building <- relative_abundance_building > 0.0005
abundant_building_taxa <- prune_taxa(abundant_building, building)

#set taxonomic level for analysis
abundant_building_genera <- tax_glom(abundant_building_taxa, taxrank = "Genus")
abundant_building_genera

#comparing plastic (reference) vs wood

sample_data(abundant_building_genera)$orig_env_material <-
  factor(sample_data(abundant_building_genera)$orig_env_material,
         levels = c("plastic", "wood"))

deseq_building <- phyloseq_to_deseq2(abundant_building_genera, ~ orig_env_material)
geo_means <- apply(counts(deseq_building), 1, calculate_gm_mean)
deseq_building <- estimateSizeFactors(deseq_building, geoMeans = geo_means)
#Encountered an error here...I swapped species to genus and it worked.
deseq_building <- DESeq(deseq_building, fitType = "local")

building_diff_abund <- results(deseq_building)


#choosing 0.05 as our alpha level

alpha <- 0.05
significant_building <- as.data.frame(building_diff_abund)
significant_building <- filter(significant_building, padj < alpha)

#merging the table with signifcant results with the table of taxonomic information. 

genera_df <- as.data.frame(tax_table(abundant_building_genera))
significant_building <- merge(significant_building, genera_df, by = "row.names")
significant_building <- arrange(significant_building, log2FoldChange)

dim(significant_building)

significant_building

#Generating the ggplot

significant_building <- mutate(significant_building,
                               Genus = factor(Genus, levels = Genus))

ggplot(significant_building, aes(x = log2FoldChange, y = Genus)) +
  geom_bar(stat = "identity") +
  labs(title = "Differential abundant genera",
       x = expression(log[2]~fold~change),
       y = "Genus") +
  theme_bw()

#creating relative abundance plot of g_Staphylococcus

# Step 2
building <- subset_samples(physeq, env_feature == "building")

# Step 4
building_RA <- transform_sample_counts(building, calculate_relative_abundance)

# Step 5
# You must use the phyloseq object with count data (i.e. before RA conversion) to determine the abundance
building_counts <- taxa_sums(building)
relative_abundance_building <- calculate_relative_abundance(building_counts)
abundant_building <- relative_abundance_building > 0.0005
abundant_building_RA_taxa <- prune_taxa(abundant_building, building_RA)

# Step 6
abundant_building_RA_genera <-  tax_glom(abundant_building_RA_taxa, taxrank = "Genus")
staphylococcus <- subset_taxa(abundant_building_RA_genera, Genus == "g__Staphylococcus")
otu_table(staphylococcus)

#transform the data fram from wide to long format
staphylococcus_long <- psmelt(staphylococcus)
staphylococcus_long

#creating ggplot for staphylococcus

ggplot(staphylococcus_long)

ggplot(staphylococcus_long, aes(x = orig_env_material, y = Abundance))

ggplot(staphylococcus_long, aes(x = orig_env_material, y = Abundance)) +
  geom_boxplot() 

ggplot(staphylococcus_long, aes(x = orig_env_material, y = Abundance)) +
  geom_boxplot() +
  labs(title = "Relative abundance of Staphylococcus",
       x     = "Surface Type",
       y     = "Relative Abundance")

ggplot(staphylococcus_long, aes(x = orig_env_material, y = Abundance, fill = orig_env_material)) +
  geom_boxplot() +
  labs(title = "Relative abundance of Staphylococcus",
       x     = "Surface Type",
       y     = "Relative Abundance")

p <- ggplot(staphylococcus_long, aes(x = orig_env_material, y = Abundance, fill = orig_env_material)) +
  geom_boxplot() +
  labs(title = "Relative abundance of Staphylococcus",
       x     = "Surface Type",
       y     = "Relative Abundance")

p + theme_bw()

p <- p + guides(fill = FALSE)
p
p + theme_bw()

#creating relative abundance plot of g_Tsukamurella

# Step 2
building <- subset_samples(physeq, env_feature == "building")

# Step 4
building_RA <- transform_sample_counts(building, calculate_relative_abundance)

# Step 5
# You must use the phyloseq object with count data (i.e. before RA conversion) to determine the abundance
building_counts <- taxa_sums(building)
relative_abundance_building <- calculate_relative_abundance(building_counts)
abundant_building <- relative_abundance_building > 0.0005
abundant_building_RA_taxa <- prune_taxa(abundant_building, building_RA)

# Step 6
abundant_building_RA_genera <-  tax_glom(abundant_building_RA_taxa, taxrank = "Genus")
tsukamurella <- subset_taxa(abundant_building_RA_genera, Genus == "g__Tsukamurella")
otu_table(tsukamurella)

#transform the data fram from wide to long format
tsukamurella_long <- psmelt(tsukamurella)
tsukamurella_long

#creating ggplot for tsukamurella

ggplot(tsukamurella_long)

ggplot(tsukamurella_long, aes(x = orig_env_material, y = Abundance))

ggplot(tsukamurella_long, aes(x = orig_env_material, y = Abundance)) +
  geom_boxplot() 

ggplot(tsukamurella_long, aes(x = orig_env_material, y = Abundance)) +
  geom_boxplot() +
  labs(title = "Relative abundance of tsukamurella",
       x     = "Surface Type",
       y     = "Relative Abundance")

ggplot(tsukamurella_long, aes(x = orig_env_material, y = Abundance, fill = orig_env_material)) +
  geom_boxplot() +
  labs(title = "Relative abundance of tsukamurella",
       x     = "Surface Type",
       y     = "Relative Abundance")

p <- ggplot(tsukamurella_long, aes(x = orig_env_material, y = Abundance, fill = orig_env_material)) +
  geom_boxplot() +
  labs(title = "Relative abundance of tsukamurella",
       x     = "Surface Type",
       y     = "Relative Abundance")

#creating relative abundance plot of g__Rothia

# Step 2
building <- subset_samples(physeq, env_feature == "building")

# Step 4
building_RA <- transform_sample_counts(building, calculate_relative_abundance)

# Step 5
# You must use the phyloseq object with count data (i.e. before RA conversion) to determine the abundance
building_counts <- taxa_sums(building)
relative_abundance_building <- calculate_relative_abundance(building_counts)
abundant_building <- relative_abundance_building > 0.0005
abundant_building_RA_taxa <- prune_taxa(abundant_building, building_RA)

# Step 6
abundant_building_RA_genera <-  tax_glom(abundant_building_RA_taxa, taxrank = "Genus")
rothia <- subset_taxa(abundant_building_RA_genera, Genus == "g__Rothia")
otu_table(rothia)

#transform the data fram from wide to long format
rothia_long <- psmelt(rothia)
rothia_long

#creating ggplot for rothia

ggplot(rothia_long)

ggplot(rothia_long, aes(x = orig_env_material, y = Abundance))

ggplot(rothia_long, aes(x = orig_env_material, y = Abundance)) +
  geom_boxplot() 

ggplot(rothia_long, aes(x = orig_env_material, y = Abundance)) +
  geom_boxplot() +
  labs(title = "Relative abundance of rothia",
       x     = "Surface Type",
       y     = "Relative Abundance")

ggplot(rothia_long, aes(x = orig_env_material, y = Abundance, fill = orig_env_material)) +
  geom_boxplot() +
  labs(title = "Relative abundance of rothia",
       x     = "Surface Type",
       y     = "Relative Abundance")

p <- ggplot(rothia_long, aes(x = orig_env_material, y = Abundance, fill = orig_env_material)) +
  geom_boxplot() +
  labs(title = "Relative abundance of rothia",
       x     = "Surface Type",
       y     = "Relative Abundance")

#facets

library(ggplot2)

otu_table(abundant_building_RA_genera)

abundant_building_RA_genera <-  tax_glom(abundant_building_RA_taxa, taxrank = "Genus")
abundant_building_RA_genera_long <- subset_taxa(abundant_building_RA_genera, Genus != "g__Aeromonas")
abundant_building_RA_genera_long1 <- subset_taxa(abundant_building_RA_genera_long, Genus != "g__Cutibacterium")
abundant_building_RA_genera_long2 <- subset_taxa(abundant_building_RA_genera_long1, Genus != "g__Delftia")
abundant_building_RA_genera_long3 <- subset_taxa(abundant_building_RA_genera_long2, Genus != "g__Kocuria")
abundant_building_RA_genera_long4 <- subset_taxa(abundant_building_RA_genera_long3, Genus != "g__Pseudomonas")
abundant_building_RA_genera_long5 <- subset_taxa(abundant_building_RA_genera_long4, Genus != "g__Roseomonas")
abundant_building_RA_genera_long6 <- subset_taxa(abundant_building_RA_genera_long5, Genus != "g__Sphingobacterium")
abundant_building_RA_genera_long7 <- subset_taxa(abundant_building_RA_genera_long6, Genus != "g__Stenotrophomonas")


#transform the data fram from wide to long format
abundant_building_RA_genera_long7_final <- psmelt(abundant_building_RA_genera_long7)
abundant_building_RA_genera_long7_final



ggplot(abundant_building_RA_genera_long7_final)
p <- ggplot(abundant_building_RA_genera_long7_final, aes(x = orig_env_material, y = Abundance, fill = orig_env_material)) +
  geom_boxplot() + facet_grid(~Genus)
p <- p + facet_wrap(~Genus, nrow=6, scales='free') + labs(x = "Original Environment Material", y = "Abundance")
p <- p + guides(fill = FALSE)
p <- p + theme_bw()
p

#set taxonomic level for analysis
abundant_building_genera <- tax_glom(abundant_building_taxa, taxrank = "Genus")
abundant_building_genera

#comparing plastic (reference) vs wood

sample_data(abundant_building_genera)$orig_env_material <-
  factor(sample_data(abundant_building_genera)$orig_env_material,
         levels = c("plastic", "wood"))

deseq_building <- phyloseq_to_deseq2(abundant_building_genera, ~ orig_env_material)
geo_means <- apply(counts(deseq_building), 1, calculate_gm_mean)
deseq_building <- estimateSizeFactors(deseq_building, geoMeans = geo_means)
#Encountered an error here...I swapped species to genus and it worked.
deseq_building <- DESeq(deseq_building, fitType = "local")

building_diff_abund <- results(deseq_building)


#choosing 0.05 as our alpha level

alpha <- 0.05
significant_building <- as.data.frame(building_diff_abund)
significant_building <- filter(significant_building, padj < alpha)

#merging the table with signifcant results with the table of taxonomic information. 

genera_df <- as.data.frame(tax_table(abundant_building_genera))
significant_building <- merge(significant_building, genera_df, by = "row.names")
significant_building <- arrange(significant_building, log2FoldChange)

dim(significant_building)

significant_building

#Generating the ggplot

significant_building <- mutate(significant_building,
                               Genus = factor(Genus, levels = Genus))

ggplot(significant_building, aes(x = log2FoldChange, y = Genus)) +
  geom_bar(stat = "identity") +
  labs(title = "Differential abundant genera",
       x = expression(log[2]~fold~change),
       y = "Genus") +
  theme_bw()

#creating relative abundance plot of g_Staphylococcus

# Step 2
building <- subset_samples(physeq, env_feature == "building")

# Step 4
building_RA <- transform_sample_counts(building, calculate_relative_abundance)

# Step 5
# You must use the phyloseq object with count data (i.e. before RA conversion) to determine the abundance
building_counts <- taxa_sums(building)
relative_abundance_building <- calculate_relative_abundance(building_counts)
abundant_building <- relative_abundance_building > 0.0005
abundant_building_RA_taxa <- prune_taxa(abundant_building, building_RA)

# Step 6
abundant_building_RA_genera <-  tax_glom(abundant_building_RA_taxa, taxrank = "Genus")
staphylococcus <- subset_taxa(abundant_building_RA_genera, Genus == "g__Staphylococcus")
otu_table(staphylococcus)

#transform the data fram from wide to long format
staphylococcus_long <- psmelt(staphylococcus)
staphylococcus_long

#creating ggplot

ggplot(staphylococcus_long)

ggplot(staphylococcus_long, aes(x = orig_env_material, y = Abundance))

ggplot(staphylococcus_long, aes(x = orig_env_material, y = Abundance)) +
  geom_boxplot() 

ggplot(staphylococcus_long, aes(x = orig_env_material, y = Abundance)) +
  geom_boxplot() +
  labs(title = "Relative abundance of Staphylococcus",
       x     = "Surface Type",
       y     = "Relative Abundance")

ggplot(staphylococcus_long, aes(x = orig_env_material, y = Abundance, fill = orig_env_material)) +
  geom_boxplot() +
  labs(title = "Relative abundance of Staphylococcus",
       x     = "Surface Type",
       y     = "Relative Abundance")

p <- ggplot(staphylococcus_long, aes(x = orig_env_material, y = Abundance, fill = orig_env_material)) +
  geom_boxplot() +
  labs(title = "Relative abundance of Staphylococcus",
       x     = "Surface Type",
       y     = "Relative Abundance")

p + theme_bw()

p <- p + guides(fill = FALSE)
p
p + theme_bw()

#creating relative abundance plot of g_Tsukamurella

# Step 2
building <- subset_samples(physeq, env_feature == "building")

# Step 4
building_RA <- transform_sample_counts(building, calculate_relative_abundance)

# Step 5
# You must use the phyloseq object with count data (i.e. before RA conversion) to determine the abundance
building_counts <- taxa_sums(building)
relative_abundance_building <- calculate_relative_abundance(building_counts)
abundant_building <- relative_abundance_building > 0.0005
abundant_building_RA_taxa <- prune_taxa(abundant_building, building_RA)

# Step 6
abundant_building_RA_genera <-  tax_glom(abundant_building_RA_taxa, taxrank = "Genus")
tsukamurella <- subset_taxa(abundant_building_RA_genera, Genus == "g__Tsukamurella")
otu_table(tsukamurella)

#transform the data fram from wide to long format
tsukamurella_long <- psmelt(tsukamurella)
tsukamurella_long

#creating ggplot for tsukamurella

ggplot(tsukamurella_long)

ggplot(tsukamurella_long, aes(x = orig_env_material, y = Abundance))

ggplot(tsukamurella_long, aes(x = orig_env_material, y = Abundance)) +
  geom_boxplot() 

ggplot(tsukamurella_long, aes(x = orig_env_material, y = Abundance)) +
  geom_boxplot() +
  labs(title = "Relative abundance of tsukamurella",
       x     = "Surface Type",
       y     = "Relative Abundance")

ggplot(tsukamurella_long, aes(x = orig_env_material, y = Abundance, fill = orig_env_material)) +
  geom_boxplot() +
  labs(title = "Relative abundance of tsukamurella",
       x     = "Surface Type",
       y     = "Relative Abundance")

p <- ggplot(tsukamurella_long, aes(x = orig_env_material, y = Abundance, fill = orig_env_material)) +
  geom_boxplot() +
  labs(title = "Relative abundance of tsukamurella",
       x     = "Surface Type",
       y     = "Relative Abundance")

#creating relative abundance plot of g__Rothia

# Step 2
building <- subset_samples(physeq, env_feature == "building")

# Step 4
building_RA <- transform_sample_counts(building, calculate_relative_abundance)

# Step 5
# You must use the phyloseq object with count data (i.e. before RA conversion) to determine the abundance
building_counts <- taxa_sums(building)
relative_abundance_building <- calculate_relative_abundance(building_counts)
abundant_building <- relative_abundance_building > 0.0005
abundant_building_RA_taxa <- prune_taxa(abundant_building, building_RA)

# Step 6
abundant_building_RA_genera <-  tax_glom(abundant_building_RA_taxa, taxrank = "Genus")
rothia <- subset_taxa(abundant_building_RA_genera, Genus == "g__Rothia")
otu_table(rothia)

#transform the data fram from wide to long format
rothia_long <- psmelt(rothia)
rothia_long

#creating ggplot for rothia

ggplot(rothia_long)

ggplot(rothia_long, aes(x = orig_env_material, y = Abundance))

ggplot(rothia_long, aes(x = orig_env_material, y = Abundance)) +
  geom_boxplot() 

ggplot(rothia_long, aes(x = orig_env_material, y = Abundance)) +
  geom_boxplot() +
  labs(title = "Relative abundance of rothia",
       x     = "Surface Type",
       y     = "Relative Abundance")

ggplot(rothia_long, aes(x = orig_env_material, y = Abundance, fill = orig_env_material)) +
  geom_boxplot() +
  labs(title = "Relative abundance of rothia",
       x     = "Surface Type",
       y     = "Relative Abundance")

p <- ggplot(rothia_long, aes(x = orig_env_material, y = Abundance, fill = orig_env_material)) +
  geom_boxplot() +
  labs(title = "Relative abundance of rothia",
       x     = "Surface Type",
       y     = "Relative Abundance")

#facets

library(ggplot2)

otu_table(abundant_building_RA_genera)

abundant_building_RA_genera <-  tax_glom(abundant_building_RA_taxa, taxrank = "Genus")
abundant_building_RA_genera_long <- subset_taxa(abundant_building_RA_genera, Genus != "g__Aeromonas")
abundant_building_RA_genera_long1 <- subset_taxa(abundant_building_RA_genera_long, Genus != "g__Cutibacterium")
abundant_building_RA_genera_long2 <- subset_taxa(abundant_building_RA_genera_long1, Genus != "g__Delftia")
abundant_building_RA_genera_long3 <- subset_taxa(abundant_building_RA_genera_long2, Genus != "g__Kocuria")
abundant_building_RA_genera_long4 <- subset_taxa(abundant_building_RA_genera_long3, Genus != "g__Pseudomonas")
abundant_building_RA_genera_long5 <- subset_taxa(abundant_building_RA_genera_long4, Genus != "g__Roseomonas")
abundant_building_RA_genera_long6 <- subset_taxa(abundant_building_RA_genera_long5, Genus != "g__Sphingobacterium")
abundant_building_RA_genera_long7 <- subset_taxa(abundant_building_RA_genera_long6, Genus != "g__Stenotrophomonas")


#transform the data fram from wide to long format
abundant_building_RA_genera_long7_final <- psmelt(abundant_building_RA_genera_long7)
abundant_building_RA_genera_long7_final



ggplot(abundant_building_RA_genera_long7_final)
p <- ggplot(abundant_building_RA_genera_long7_final, aes(x = orig_env_material, y = Abundance, fill = orig_env_material)) +
  geom_boxplot() + facet_grid(~Genus)
p <- p + facet_wrap(~Genus, nrow=6, scales='free') + labs(x = "Original Environment Material", y = "Abundance")
p <- p + guides(fill = FALSE)
p <- p + theme_bw()
p
